# mypy-boto3-xray

[![PyPI - mypy-boto3-xray](https://img.shields.io/pypi/v/mypy-boto3-xray.svg?color=blue)](https://pypi.org/project/mypy-boto3-xray)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-xray.svg?color=blue)](https://pypi.org/project/mypy-boto3-xray)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

Type annotations for
[boto3.XRay 1.13.13](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/xray.html#XRay) service
compatible with [mypy](https://github.com/python/mypy), [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/) and other tools.

Generated by [mypy-boto3-buider 1.0.9](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

- [mypy-boto3-xray](#mypy-boto3-xray)
  - [How to use](#how-to-use)
    - [Type checking](#type-checking)
  - [How it works](#how-it-works)

## How to use

### Type checking

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `XRay` service.

```bash
python -m pip install boto3-stubs[xray]

# update installed packages index
mypy_boto3
```

Use `boto3` with `mypy_boto3` in your project and enjoy type checking and auto-complete.

```python
import boto3

from mypy_boto3 import xray
# alternative import if you do not want to install mypy_boto3 package
# import mypy_boto3_xray as xray

# Use this client as usual, now mypy can check if your code is valid.
# Check if your IDE supports function overloads,
# you probably do not need explicit type annotations
# client = boto3.client("xray")
client: xray.XRayClient = boto3.client("xray")

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: xray.XRayClient = session.client("xray")


# Paginators need type annotation on creation
batch_get_traces_paginator: xray.BatchGetTracesPaginator = client.get_paginator("batch_get_traces")
get_groups_paginator: xray.GetGroupsPaginator = client.get_paginator("get_groups")
get_sampling_rules_paginator: xray.GetSamplingRulesPaginator = client.get_paginator("get_sampling_rules")
get_sampling_statistic_summaries_paginator: xray.GetSamplingStatisticSummariesPaginator = client.get_paginator("get_sampling_statistic_summaries")
get_service_graph_paginator: xray.GetServiceGraphPaginator = client.get_paginator("get_service_graph")
get_time_series_service_statistics_paginator: xray.GetTimeSeriesServiceStatisticsPaginator = client.get_paginator("get_time_series_service_statistics")
get_trace_graph_paginator: xray.GetTraceGraphPaginator = client.get_paginator("get_trace_graph")
get_trace_summaries_paginator: xray.GetTraceSummariesPaginator = client.get_paginator("get_trace_summaries")
```

## How it works

Fully automated [builder](https://github.com/vemel/mypy_boto3_builder) carefully generates
type annotations for each service, patiently waiting for `boto3` updates. It delivers
a drop-in type annotations for you and makes sure that:

- All available `boto3` services are covered.
- Each public class and method of every `boto3` service gets valid type annotations
  extracted from the documentation (blame `botocore` docs if types are incorrect).
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) for readability.